@@ -25,3 +25,10 @@ class Role_Error(ConfigError):
 
     def __str__(self):
         return "角色类发生错误！{}".format(self.info)
+
+class Fall_Error(ConfigError):
+    def __init__(self, info=''):
+        self.info = info
+
+    def __str__(self):
+        return "下落物体类发生错误！{}".format(self.info)
\ No newline at end of file
